@@ -28,7 +28,7 @@ config = {
 					"(^[^_]+)",   # first lex
 					#"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)$", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
 					#"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",  # remove _NP5,  _NP5 => _NP 
-					"(_[a-zA-Z,\\-\\.\\'\\$]+)",  # _^ _ADJ _, _NOUN _VERB
+					"(_[a-zA-Z,\\-\\.\\'\\$\\*]+)",  # _^ _ADJ _, _NOUN _VERB
 					#"(_[^\\w]+)_",
 					#"([^\\w])_"
 				  ]
@@ -39,6 +39,7 @@ config = {
 					"^ => ALPHA",
 					", => ALPHA",
 					"$ => ALPHA",
+					"* => ALPHA",
 					"_ => ALPHA",
 					". => ALPHA",
 					"- => ALPHA",
@@ -92,6 +93,7 @@ config = {
 			"pterm": { "type": "text", "analyzer": "path_ana"  }, # path term
 			"postag": { "type": "text", "analyzer": "postag_ana"},
 			"skenp": { "type": "text", "analyzer": "postag_ana"},
+			"hyb": { "type": "text", "analyzer": "postag_ana"}, # 2023.3.16
 			"sentgram": { "type": "text", "analyzer": "postag_ana","fielddata":"true"}, # simple_complex_headpp compound_question_itis_svo
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
@@ -106,6 +108,7 @@ config = {
 			"offset": { "type": "float"},
 			"final_score": { "type": "float"},
 			"sid": { "type": "keyword"},
+			"sntid": { "type": "keyword"},
 			"id": { "type": "keyword"},
 			"rid": { "type": "keyword"},
 			"did": { "type": "keyword"},
