@@ -1,5 +1,5 @@
 # 2022.3.10
-import requests,re,time
+import requests,re,time,sqlite3,itertools
 from collections import	Counter, defaultdict
 now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))
 
@@ -7,6 +7,22 @@ import hashlib
 sntmd5	= lambda sntarr: " ".join([hashlib.md5(snt.strip().lower().encode("utf-8")).hexdigest() for snt in sntarr if len(snt) > 1])
 md5text	= lambda text: hashlib.md5(text.strip().encode("utf-8")).hexdigest()
 
+def sqlite_conn(sql:str="create table nac( name varchar(64) not null , attr varchar(64) not null, count int not null default 0, primary key(name, attr) ) without rowid") :
+	conn  =	sqlite3.connect(outfile, check_same_thread=False) 
+	conn.execute(sql)
+	conn.execute('PRAGMA synchronous=OFF')
+	conn.execute('PRAGMA case_sensitive_like = 1')
+	conn.commit()
+	return conn 
+
+toks_product = lambda snt='one two/x three/y': [ar for ar in itertools.product( * [a.strip().split('/') for a in snt.strip().split()]) ]  #[('one', 'two', 'three'),  ('one', 'two', 'y'), ('one', 'x', 'three'), ('one', 'x', 'y')]
+def cands_product(q='one two/ three/'):
+	''' {'one three', 'one two', 'one two three'} '''
+	if not ' ' in q : return set(q.strip().split('/'))
+	arr = [a.strip().split('/') for a in q.split()]
+	res = [' '.join([a for a in ar if a]) for ar in itertools.product( * arr)]
+	return set( [a.strip() for a in res if ' ' in a]) 
+
 from math import log as ln
 def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.html
 	try:
@@ -105,25 +121,4 @@ def traverse(t, label='NP', f = lambda t:  print(t.pos()) ):
               traverse(child, label, f)
 
 if __name__ == '__main__': 
-	pass 
-	#logger = getlog()
-	#print (logger) 
-
-'''
-def  si_to_es(si, index, batch=10000, eshost='127.0.0.1',esport=9200): 
-	from elasticsearch import Elasticsearch,helpers
-	es = Elasticsearch([ f"http://{eshost}:{esport}" ])  
-	print (index, es, flush=True) 
-	actions=[]
-	for s,i in si.items() if isinstance(si, dict) else si: 
-		try:
-			actions.append( {'_op_type':'index', '_index':index, "_id": s, "_source":{"s": s, "i":i} })
-			if len(actions) >= batch: 
-				helpers.bulk(client=es,actions=actions, raise_on_error=False)
-				print ( actions[-1], flush=True)
-				actions = []
-		except Exception as e:
-			print("ex:", e)	
-	if actions : helpers.bulk(client=es,actions=actions, raise_on_error=False)
-	print(">>load finished:" , index )
-'''
\ No newline at end of file
+	pass 
\ No newline at end of file
