@@ -21,7 +21,8 @@ def unmasker_single(body:str="Parents * much importance to education.", options:
 	'''  2022.8.6 '''
 	rows = unmasker(body,  model=model, topk=topk)
 	arr  = options.strip().split(sepa) 
-	return {"rank": [ (row['word'], row['score'], i+1) for i, row in enumerate(rows) if row['word'] in arr ], "cands": rows}
+	#return {"rank": [ (row['word'], row['score'], i+1) for i, row in enumerate(rows) if row['word'] in arr ], "cands": rows}
+	return {"rank": [ {"word":row['word'], "prob": 100 * row['score'], "rank":i+1} for i, row in enumerate(rows) if row['word'] in arr ], "cands": rows}
 
 @app.get('/unmaskers', tags=["unmasker"])
 def unmaskers(q:str="The goal of life is *.", models:str='native,nju', topk:int=10): 
@@ -38,5 +39,22 @@ def unmasker_html(q:str="The goal of life is *.", model:str='native', topk:int=1
 	snts = "\n".join([f"<li><span style='font-weight:{int(10*row['score']/maxscore)}00'>{row.get('word','')}<span></li>" for row in rows])
 	return HTMLResponse(content=f"<ol>{snts}</ol>")
 
+from functools import lru_cache
+@lru_cache(maxsize=128)
+def pos_dic(pos:str='VBD'):
+	return requests.get(f"http://files.jukuu.com:8001/static/yulk/lemset-{pos}.json").json()
+
+@app.get('/snt/cloze', tags=["unmasker"])
+def snt_cloze(snt:str="Parents * much importance to education.", word:str='attached', pos:str='VBD', model:str='native', topk:int=1000): 
+	''' model: native/nju/fengtai/sino/sci/gblog/twit, 2023.2.27	'''
+	rows	= unmasker(snt, model, topk, True)
+	words	=  { row["token_str"] : round(row["score"], 4) for row in rows }
+	posdic	= pos_dic(pos) 
+	posw	= {s:i for s,i in words.items() if s in posdic}
+
+	cands = requests.post(f"http://cpu76.wrask.com:8002/gensim/distance/words?src={word}",json=[s for s,i in posw.items()]).json() #[{'word': 'have', 'distance': 0.8523787260055542},
+	cands.sort(key=lambda a:a['distance'])
+	return [ dict(row, **{"score": posw.get(row['word'],0) })  for row in cands]
+
 if __name__ == '__main__': #print (models['native']("The goal of life is [MASK]."))
 	print(unmasker_single())
\ No newline at end of file
